@@ -2,9 +2,9 @@
 #define GETOPINIONSINK_H
 #include <QtCore>
 #include <mbarcode-qt/plugininterfaces.h>
-#include <mbarcode-qt/sinkplugin.h>
+#include <mbarcode-qt/pluginaction.h>
 class Plugin;
-class GetOpinionSink: public QObject, public SinkPlugin
+class GetOpinionSink: public QObject, public PluginAction
 {
     Q_OBJECT
 
@@ -12,13 +12,15 @@ public:
     // inherited virtuals
     GetOpinionSink(const PluginInterface *interface);
 
-    QString getName() {return "Informed Individual Get Opinion Sink Plugin";};
-    QString getText() {return "Get Opinion from Informed Individual"; }
-    bool isReady() {return true;};
+    QString getName() {return "Informed Individual Get Opinion Sink Plugin";}
+    QString getText() {return "Rating from Informed Individual"; }
+    QImage getImage();
+    bool isReady() {return true;}
     void clickAction(QWidget *parentWindow);
     void setPlugin(Plugin *plugin);
 private:
     Plugin *plugin;
+    QImage image;
 };
 
 #endif // GETOPINIONSINK_H
